@@ -1,5 +1,4 @@
-/* Copyright (C) 1995-1999, 2000, 2001, 2002, 2003, 2004, 2006, 2008,
- *   2009, 2010, 2011, 2012, 2013, 2014, 2015 Free Software Foundation, Inc.
+/* Copyright (C) 1995-2004, 2006, 2008-2019 Free Software Foundation, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -194,9 +193,9 @@ SCM_DEFINE (scm_current_pstate, "current-pstate", 0, 0, 0,
 static SCM
 make_print_state (void)
 {
-  SCM print_state
-    = scm_make_struct (scm_print_state_vtable, SCM_INUM0, SCM_EOL);
+  SCM print_state = scm_make_struct_no_tail (scm_print_state_vtable, SCM_EOL);
   scm_print_state *pstate = SCM_PRINT_STATE (print_state);
+  pstate->handle = print_state;
   pstate->ref_vect = scm_c_make_vector (PSTATE_SIZE, SCM_UNDEFINED);
   pstate->ceiling = SCM_SIMPLE_VECTOR_LENGTH (pstate->ref_vect);
   pstate->highlight_objects = SCM_EOL;
@@ -1161,14 +1160,14 @@ SCM_DEFINE (scm_simple_format, "simple-format", 2, 0, 1,
 	    continue;
 	  default:
 	    SCM_MISC_ERROR ("FORMAT: Unsupported format option ~~~A - use (ice-9 format) instead",
-			    scm_list_1 (SCM_MAKE_CHAR (scm_i_string_ref (message, p))));
+			    scm_list_1 (scm_i_make_char (scm_i_string_ref (message, p))));
 	    
 	  }
 
 
 	if (!scm_is_pair (args))
 	  SCM_MISC_ERROR ("FORMAT: Missing argument for ~~~A",
-			  scm_list_1 (SCM_MAKE_CHAR (scm_i_string_ref (message, p))));
+			  scm_list_1 (scm_i_make_char (scm_i_string_ref (message, p))));
 			  		
 	scm_lfwrite_substr (message, start, p - 1, port);
 	/* we pass destination here */
@@ -1290,9 +1289,9 @@ scm_init_print ()
 {
   SCM type;
 
-  type = scm_make_vtable (scm_from_locale_string (SCM_PRINT_STATE_LAYOUT),
+  type = scm_make_vtable (scm_from_utf8_string (SCM_PRINT_STATE_LAYOUT),
                           SCM_BOOL_F);
-  scm_set_struct_vtable_name_x (type, scm_from_latin1_symbol ("print-state"));
+  scm_set_struct_vtable_name_x (type, scm_from_utf8_symbol ("print-state"));
   scm_print_state_vtable = type;
 
   /* Don't want to bind a wrapper class in GOOPS, so pass 0 as arg1. */
@@ -1303,9 +1302,9 @@ scm_init_print ()
 
   scm_init_opts (scm_print_options, scm_print_opts);
   scm_print_opts[SCM_PRINT_HIGHLIGHT_PREFIX_I].val =
-    SCM_UNPACK (scm_from_locale_string ("{"));
+    SCM_UNPACK (scm_from_utf8_string ("{"));
   scm_print_opts[SCM_PRINT_HIGHLIGHT_SUFFIX_I].val =
-    SCM_UNPACK (scm_from_locale_string ("}"));
+    SCM_UNPACK (scm_from_utf8_string ("}"));
   scm_print_opts[SCM_PRINT_KEYWORD_STYLE_I].val = SCM_UNPACK (sym_reader);
 }
 
